PrinComp<-function(X,save.plots=FALSE,produce.plots=TRUE)
{
  ###############covariance-based results
  #auxilary routine to find covariance matrix of a column-centered X
  my.cov<-function(X){
    X=as.matrix(X);t(X)%*% scale(diag(nrow(X)),scale=FALSE)%*%X/nrow(X)}
  #obtain cov matrix, eigen values and vectors
  S<-my.cov(X)
  outS<-eigen(S)
  T1<-outS$vectors
  D1<-outS$values
  #correct the signs in columns of T1
  if((sum(sign(T1[,1])) < 0))
    T1<-sweep(T1,2,FUN="*", rep(-1,ncol(T1))^(1:ncol(T1)) )
  if( (sum(sign(T1[,2])) < 0))
    T1<-sweep(T1,2,FUN="*", rep(-1,ncol(T1))^(1+(1:ncol(T1)) ) )
  #reconstruct (center columns in X) 
  Y1<-as.matrix(scale(X,scale=FALSE))%*%T1
  #get the %s
  perc1<-round(100*D1/sum(D1),4)
  cperc1<-cumsum(perc1)
  ###############correlation-based results
  R<-cor(X)
  outR<-eigen(R)
  T2<-outR$vectors
  D2<-outR$values
  #correct the signs in columns of T2
  if((sum(sign(T2[,1])) < 0))
    T2<-sweep(T2,2,FUN="*", rep(-1,ncol(T2))^(1:ncol(T2)) )
  if( (sum(sign(T2[,2])) < 0))
    T2<-sweep(T2,2,FUN="*", rep(-1,ncol(T2))^(1+(1:ncol(T2)) ) )
  #reconstruct (standardize columns in X)
  Y2<-as.matrix(scale(X))%*%T2
  #get the %s
  perc2<-round(100*D2/sum(D2),4) 
  cperc2<-cumsum(perc2)
###############################plots
require(ggplot2)
pca2.df<-data.frame(PC1=c(Y1[,1],Y2[,1]),
                    PC2=c(Y1[,2],Y2[,2]),
                    type=rep(c("cov","cor"),
                    each=nrow(X)),label=rep(rownames(X),2))
  labels=(c(paste("PCA from covariance matrix (",cperc1[2],"%)",sep=""),
            paste("PCA from correlation matrix (",cperc2[2],"%)",sep="")))
  
  pca2.df$type<-factor(pca2.df$type,levels=rev(levels(pca2.df$type)),
                       labels=labels)
  
p2<-ggplot(data=pca2.df,aes(x=PC1,y=PC2))
p2<-p2+geom_point()+facet_wrap(~type,scales="free",ncol=1) + 
scale_y_continuous("2nd Principal Component")+scale_x_continuous("1st Principal Component")
p2 <- p2 + geom_text(data=pca2.df, hjust=+0.5,vjust=-0.5, 
                    aes(x=PC1, y=PC2, label=label), size=4) +theme_bw() 
  
scree.df<-data.frame(index=rep(1:ncol(X),2),
                   percent=c(perc1,perc2),type=rep(c("cov","cor"),each=ncol(X)))
  labels=c("Scree graph from covariance matrix",
            "Scree graph from correlation matrix")  
  
  scree.df$type<-factor(scree.df$type,levels=rev(levels(scree.df$type)),
                        labels=labels)
                        
s<-ggplot(data=scree.df,aes(x=index,y=percent))
s<-s+geom_point(size=4)+geom_line()+facet_wrap(~type,scales="free",ncol=1) 
s<-s+scale_x_continuous("Principal Components")
s<-s+ scale_y_continuous("Percentage of explained variability")+theme_bw()
#############################################producing plots
if(produce.plots==TRUE)
{
graphics.off()
grid.newpage()
pushViewport(viewport(layout = grid.layout(1, 2)))
print(p2, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
print(s, vp = viewport(layout.pos.row = 1, layout.pos.col = 2))
}
#############################################saving plots
if(save.plots==TRUE)
{
graphics.off()
postscript("plot1.eps",height=8,width=16)
grid.newpage()
pushViewport(viewport(layout = grid.layout(1, 2)))
print(p2, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
print(s, vp = viewport(layout.pos.row = 1, layout.pos.col = 2))
dev.off()
}#end of if plots
list(T1=T1,Y1=Y1,acum1=cperc1,T2=T2,Y2=Y2,acum2=cperc2,D1=D1,D2=D2)
}#end of PrinComp
