# PrinCompCor
#
# Function 'PrinCompCor' finds principal components
# of an  (n x p) matrix X based on the correlation matrix.
# Inputs: X
# Outputs: 
#          T: PCs based on a covariance matrix (R)
#          Y: corresponding data 
#          cperc: cummulative percentages
PrinCompCor<-function(X)
{
  R<-cor(X)
  outR<-eigen(R)
  T2<-outR$vectors
  D2<-outR$values
  #correct the signs in columns of T2
  if((sum(sign(T2[,1])) < 0))
    T2<-sweep(T2,2,FUN="*", rep(-1,ncol(T2))^(1:ncol(T2)) )
  if( (sum(sign(T2[,2])) < 0))
    T2<-sweep(T2,2,FUN="*", rep(-1,ncol(T2))^(1+(1:ncol(T2)) ) )
  #reconstruct (standardize columns in X)
  Y2<-as.matrix(scale(X))%*%T2
  #get the %s
  perc2<-round(100*D2/sum(D2),4) 
  cperc2<-cumsum(perc2)
  rownames(Y2)<-rownames(X)
  list(T=T2,Y=Y2,cperc=cperc2)
}
